// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef MIMETREEPARSERNG_VERSION_H
#define MIMETREEPARSERNG_VERSION_H

#define MIMETREEPARSERNG_VERSION_STRING "6.7.2"
#define MIMETREEPARSERNG_VERSION_MAJOR 6
#define MIMETREEPARSERNG_VERSION_MINOR 7
#define MIMETREEPARSERNG_VERSION_PATCH 2
#define MIMETREEPARSERNG_VERSION ((6<<16)|(7<<8)|(2))

#endif
